<?php
/**
 * File containing the ezcWorkflowConditionIsTrue class.
 *
 * @package Workflow
 * @version 1.2
 * @copyright Copyright (C) 2005-2008 eZ systems as. All rights reserved.
 * @license http://ez.no/licenses/new_bsd New BSD License
 */

/**
 * Workflow condition that evaluates to true if the provided input is true.
 *
 * Typically used together with ezcWorkflowConditionVariable to use the
 * condition on a workflow variable.
 *
 * <code>
 * <?php
 * $condition = new ezcWorkflowConditionVariable(
 *   'variable name',
 *   new ezcWorkflowConditionIsTrue
 * );
 * ?>
 * </code>
 *
 * @package Workflow
 * @version 1.2
 */
class ezcWorkflowConditionIsTrue implements ezcWorkflowCondition
{
    /**
     * Evaluates this condition with $value and returns true if it is true and false if it is not.
     *
     * @param  mixed $value
     * @return boolean true when the condition holds, false otherwise.
     * @ignore
     */
    public function evaluate( $value )
    {
        return $value === true;
    }

    /**
     * Returns a textual representation of this condition.
     *
     * @return string
     * @ignore
     */
    public function __toString()
    {
        return 'is true';
    }
}
?>
